# Orange-Spectroscopy documentation

Orange-Spectroscopy is an add-on for Orange for the analysis of spectral data.

To use it, download and install the Quasar distribution of Orange, which comes with Orange-Spectroscopy pre-installed. You can also install it into your Orange data mining suite with the "Add-ons" menu (Options->Add-ons).

For an introduction to Orange and widgets from this add-on, see the following YouTube channels:

- Getting started with Orange - introduces data analysis with Orange
- Spectral Orange - tutorials that use the Spectroscopy add-on on spectral data

## Widgets

- Spectra
- HyperSpectra
- Interpolate
- Preprocess Spectra
- Integrate Spectra
- Multifile
- Tile File
- Average Spectra
- Interferogram to Spectrum
- Reshape Map
- PLS
- Peak Fit
- SNR

## Indices and tables

- Index
- Module Index
- Search Page